@@ -1,5 +1,7 @@
 """Entities for `io` module."""
 
+from typing import Dict, Set
+
 from graphinder.entities.pool import Url
 
-Results = dict[str, set[Url]]
+Results = Dict[str, Set[Url]]
